Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/sys Rename SB_UPDATE_TAIL() to SB_EMPTY_FIXUP(), per suggest...



details:   https://anonhg.NetBSD.org/src/rev/ac9543c76bee
branches:  trunk
changeset: 533544:ac9543c76bee
user:      thorpej <thorpej%NetBSD.org@localhost>
date:      Wed Jul 03 21:39:40 2002 +0000

description:
Rename SB_UPDATE_TAIL() to SB_EMPTY_FIXUP(), per suggestion from
Jonathan Stone.

diffstat:

 sys/dev/kttcp.c           |   8 ++++----
 sys/kern/uipc_socket.c    |  10 +++++-----
 sys/kern/uipc_socket2.c   |   8 ++++----
 sys/netccitt/if_x25subr.c |   6 +++---
 sys/netccitt/pk_output.c  |   6 +++---
 sys/netccitt/pk_usrreq.c  |   6 +++---
 sys/sys/socketvar.h       |   4 ++--
 7 files changed, 24 insertions(+), 24 deletions(-)

diffs (216 lines):

diff -r b4e298bc1d13 -r ac9543c76bee sys/netccitt/if_x25subr.c
--- a/sys/netccitt/if_x25subr.c Wed Jul 03 21:36:57 2002 +0000
+++ b/sys/netccitt/if_x25subr.c Wed Jul 03 21:39:40 2002 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: if_x25subr.c,v 1.29 2002/07/03 19:06:52 thorpej Exp $  */
+/*     $NetBSD: if_x25subr.c,v 1.30 2002/07/03 21:39:42 thorpej Exp $  */
 
 /*
  * Copyright (c) 1990, 1993
@@ -36,7 +36,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: if_x25subr.c,v 1.29 2002/07/03 19:06:52 thorpej Exp $");
+__KERNEL_RCSID(0, "$NetBSD: if_x25subr.c,v 1.30 2002/07/03 21:39:42 thorpej Exp $");
 
 #include "opt_inet.h"
 #include "opt_iso.h"
@@ -772,7 +772,7 @@
        while ((m = (s)->sb_mb) != NULL) \
                { \
                        (s)->sb_mb = m->m_nextpkt; \
-                       SB_UPDATE_TAIL((s)); \
+                       SB_EMPTY_FIXUP((s)); \
                        m->m_nextpkt = 0; \
                        sbfree((s), m); \
                        f; \
diff -r b4e298bc1d13 -r ac9543c76bee sys/netccitt/pk_output.c
--- a/sys/netccitt/pk_output.c  Wed Jul 03 21:36:57 2002 +0000
+++ b/sys/netccitt/pk_output.c  Wed Jul 03 21:39:40 2002 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: pk_output.c,v 1.17 2002/07/03 19:06:53 thorpej Exp $   */
+/*     $NetBSD: pk_output.c,v 1.18 2002/07/03 21:39:42 thorpej Exp $   */
 
 /*
  * Copyright (c) 1984 University of British Columbia.
@@ -44,7 +44,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: pk_output.c,v 1.17 2002/07/03 19:06:53 thorpej Exp $");
+__KERNEL_RCSID(0, "$NetBSD: pk_output.c,v 1.18 2002/07/03 21:39:42 thorpej Exp $");
 
 #include <sys/param.h>
 #include <sys/systm.h>
@@ -214,7 +214,7 @@
                        return (NULL);
 
                sb->sb_mb = m->m_nextpkt;
-               SB_UPDATE_TAIL(sb);
+               SB_EMPTY_FIXUP(sb);
                m->m_nextpkt = 0;
                for (n = m; n; n = n->m_next)
                        sbfree(sb, n);
diff -r b4e298bc1d13 -r ac9543c76bee sys/netccitt/pk_usrreq.c
--- a/sys/netccitt/pk_usrreq.c  Wed Jul 03 21:36:57 2002 +0000
+++ b/sys/netccitt/pk_usrreq.c  Wed Jul 03 21:39:40 2002 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: pk_usrreq.c,v 1.22 2002/07/03 19:06:54 thorpej Exp $   */
+/*     $NetBSD: pk_usrreq.c,v 1.23 2002/07/03 21:39:42 thorpej Exp $   */
 
 /*
  * Copyright (c) 1984 University of British Columbia.
@@ -44,7 +44,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: pk_usrreq.c,v 1.22 2002/07/03 19:06:54 thorpej Exp $");
+__KERNEL_RCSID(0, "$NetBSD: pk_usrreq.c,v 1.23 2002/07/03 21:39:42 thorpej Exp $");
 
 #include <sys/param.h>
 #include <sys/systm.h>
@@ -268,7 +268,7 @@
                        if (n && n->m_type == MT_OOBDATA) {
                                unsigned        len = n->m_pkthdr.len;
                                so->so_rcv.sb_mb = n->m_nextpkt;
-                               SB_UPDATE_TAIL(&so->so_rcv);
+                               SB_EMPTY_FIXUP(&so->so_rcv);
                                if (len != n->m_len &&
                                    (n = m_pullup(n, len)) == 0)
                                        break;
diff -r b4e298bc1d13 -r ac9543c76bee sys/sys/socketvar.h
--- a/sys/sys/socketvar.h       Wed Jul 03 21:36:57 2002 +0000
+++ b/sys/sys/socketvar.h       Wed Jul 03 21:39:40 2002 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: socketvar.h,v 1.53 2002/07/03 21:36:57 thorpej Exp $   */
+/*     $NetBSD: socketvar.h,v 1.54 2002/07/03 21:39:40 thorpej Exp $   */
 
 /*-
  * Copyright (c) 1982, 1986, 1990, 1993
@@ -128,7 +128,7 @@
        struct mbuf     *so_pendfree;   /* loaned-page mbufs w/ frees pending */
 };
 
-#define        SB_UPDATE_TAIL(sb)                                              \
+#define        SB_EMPTY_FIXUP(sb)                                              \
 do {                                                                   \
        if ((sb)->sb_mb == NULL) {                                      \
                (sb)->sb_mbtail = NULL;                                 \



Home | Main Index | Thread Index | Old Index
diff -r b4e298bc1d13 -r ac9543c76bee sys/dev/kttcp.c
--- a/sys/dev/kttcp.c   Wed Jul 03 21:36:57 2002 +0000
+++ b/sys/dev/kttcp.c   Wed Jul 03 21:39:40 2002 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: kttcp.c,v 1.3 2002/07/03 19:36:52 thorpej Exp $        */
+/*     $NetBSD: kttcp.c,v 1.4 2002/07/03 21:39:41 thorpej Exp $        */
 
 /*
  * Copyright (c) 2002 Wasabi Systems, Inc.
@@ -537,7 +537,7 @@
                if ((flags & MSG_PEEK) == 0) {
                        KASSERT(so->so_rcv.sb_mb == m);
                        so->so_rcv.sb_mb = nextrecord;
-                       SB_UPDATE_TAIL(&so->so_rcv);
+                       SB_EMPTY_FIXUP(&so->so_rcv);
                }
        }
        SBLASTRECORDCHK(&so->so_rcv, "kttcp_soreceive 2");
@@ -599,7 +599,7 @@
                                                so->so_rcv.sb_lastrecord = m;
                                } else {
                                        so->so_rcv.sb_mb = nextrecord;
-                                       SB_UPDATE_TAIL(&so->so_rcv);
+                                       SB_EMPTY_FIXUP(&so->so_rcv);
                                }
                                SBLASTRECORDCHK(&so->so_rcv,
                                    "kttcp_soreceive 3");
@@ -683,7 +683,7 @@
        if ((flags & MSG_PEEK) == 0) {
                if (m == 0) {
                        /*
                         * First part is an SB_UPDATE_TAIL().  Second part
                         * makes sure sb_lastrecord is up-to-date if
                         * there is still data in the socket buffer.
                         */
@@ -683,7 +683,7 @@
                if (m == 0) {
                        /*
-                        * First part is an SB_UPDATE_TAIL().  Second part
+                        * First part is an SB_EMPTY_FIXUP().  Second part
                         * makes sure sb_lastrecord is up-to-date if
                         * there is still data in the socket buffer.
diff -r b4e298bc1d13 -r ac9543c76bee sys/kern/uipc_socket.c
--- a/sys/kern/uipc_socket.c    Wed Jul 03 21:36:57 2002 +0000
+++ b/sys/kern/uipc_socket.c    Wed Jul 03 21:39:40 2002 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: uipc_socket.c,v 1.69 2002/07/03 19:06:48 thorpej Exp $ */
+/*     $NetBSD: uipc_socket.c,v 1.70 2002/07/03 21:39:41 thorpej Exp $ */
 
 /*-
  * Copyright (c) 2002 The NetBSD Foundation, Inc.
@@ -72,7 +72,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: uipc_socket.c,v 1.69 2002/07/03 19:06:48 thorpej Exp $");
+__KERNEL_RCSID(0, "$NetBSD: uipc_socket.c,v 1.70 2002/07/03 21:39:41 thorpej Exp $");
 
 #include "opt_sock_counters.h"
 #include "opt_sosend_loan.h"
@@ -995,7 +995,7 @@
                if ((flags & MSG_PEEK) == 0) {
                        KASSERT(so->so_rcv.sb_mb == m);
                        so->so_rcv.sb_mb = nextrecord;
-                       SB_UPDATE_TAIL(&so->so_rcv);
+                       SB_EMPTY_FIXUP(&so->so_rcv);
                }
        }
        SBLASTRECORDCHK(&so->so_rcv, "soreceive 2");
@@ -1082,7 +1082,7 @@
                                                so->so_rcv.sb_lastrecord = m;
                                } else {
                                        so->so_rcv.sb_mb = nextrecord;
-                                       SB_UPDATE_TAIL(&so->so_rcv);
+                                       SB_EMPTY_FIXUP(&so->so_rcv);
                                }
                                SBLASTRECORDCHK(&so->so_rcv, "soreceive 3");
                                SBLASTMBUFCHK(&so->so_rcv, "soreceive 3");
@@ -1162,7 +1162,7 @@
        if ((flags & MSG_PEEK) == 0) {
                if (m == 0) {
                        /*
                         * First part is an inline SB_UPDATE_TAIL().  Second
                         * part makes sure sb_lastrecord is up-to-date if
                         * there is still data in the socket buffer.
                         */
@@ -1162,7 +1162,7 @@
                if (m == 0) {
                        /*
-                        * First part is an inline SB_UPDATE_TAIL().  Second
+                        * First part is an inline SB_EMPTY_FIXUP().  Second
                         * part makes sure sb_lastrecord is up-to-date if
                         * there is still data in the socket buffer.
diff -r b4e298bc1d13 -r ac9543c76bee sys/kern/uipc_socket2.c
--- a/sys/kern/uipc_socket2.c   Wed Jul 03 21:36:57 2002 +0000
+++ b/sys/kern/uipc_socket2.c   Wed Jul 03 21:39:40 2002 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: uipc_socket2.c,v 1.44 2002/07/03 21:36:58 thorpej Exp $        */
+/*     $NetBSD: uipc_socket2.c,v 1.45 2002/07/03 21:39:41 thorpej Exp $        */
 
 /*
  * Copyright (c) 1982, 1986, 1988, 1990, 1993
@@ -36,7 +36,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: uipc_socket2.c,v 1.44 2002/07/03 21:36:58 thorpej Exp $");
+__KERNEL_RCSID(0, "$NetBSD: uipc_socket2.c,v 1.45 2002/07/03 21:39:41 thorpej Exp $");
 
 #include <sys/param.h>
 #include <sys/systm.h>
@@ -850,7 +850,7 @@
        } else
                sb->sb_mb = next;
        /*
         * First part is an inline SB_UPDATE_TAIL().  Second part
         * makes sure sb_lastrecord is up-to-date if we dropped
         * part of the last record.
         */
@@ -879,7 +879,7 @@
                        MFREE(m, mn);
                } while ((m = mn) != NULL);
        }
-       SB_UPDATE_TAIL(sb);
+       SB_EMPTY_FIXUP(sb);
 }
 
 /*
@@ -850,7 +850,7 @@
                sb->sb_mb = next;
        /*
-        * First part is an inline SB_UPDATE_TAIL().  Second part
+        * First part is an inline SB_EMPTY_FIXUP().  Second part
         * makes sure sb_lastrecord is up-to-date if we dropped
         * part of the last record.